@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide access to chemical element properties
 
-our $VERSION = '0.0200';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -14,7 +14,7 @@ use Text::CSV_XS ();
 use namespace::clean;
 
 
-has data => (is => 'lazy');
+has data => (is => 'lazy', init_args => undef);
 
 sub _build_data {
     my ($self) = @_;
@@ -170,13 +170,30 @@ Chemistry::PeriodicTable - Provide access to chemical element properties
 
 =head1 VERSION
 
-version 0.0200
+version 0.0201
 
 =head1 SYNOPSIS
 
   use Chemistry::PeriodicTable ();
 
-  my $pt = Chemistry::PeriodicTable->new(verbose => 1);
+  my $pt = Chemistry::PeriodicTable->new;
+
+  my $x = $pt->as_file;
+  $x = $pt->as_hash;
+  my @headers = $pt->headers;
+
+  $pt->atomic_number('H');        # 1
+  $pt->atomic_number('hydrogen'); # 1
+
+  $pt->name(1);   # Hydrogen
+  $pt->name('H'); # Hydrogen
+
+  $pt->symbol(1); # H
+  $pt->symbol('hydrogen'); # H
+
+  $pt->value('H', 'weight');               # 1.00794
+  $pt->value(118, 'weight');               # 294
+  $pt->value('hydrogen', 'Atomic Radius'); # 0.79
 
 =head1 DESCRIPTION
 
@@ -208,10 +225,10 @@ Return the data filename location.
 
   $data = $pt->as_hash;
 
-Return the data as a hash.
+Return the data as a hash reference.
 
-Keys are equal to the data column headers. See the C<headers>
-method.
+Keys are the element symbols and the values are the element
+properties.
 
 =head2 headers
 
@@ -253,14 +270,14 @@ Return the atomic number of either a symbol or name.
   $n = $pt->name($number);
   $n = $pt->name($symbol);
 
-Return the atom name of given either an atomic number or symbol.
+Return the atom name of either an atomic number or symbol.
 
 =head2 symbol
 
   $s = $pt->symbol($number);
   $s = $pt->symbol($name);
 
-Return the atomic symbol of given either an atomic number or name.
+Return the atomic symbol of either an atomic number or name.
 
 =head2 value
 
@@ -268,8 +285,8 @@ Return the atomic symbol of given either an atomic number or name.
   $v = $pt->value($name, $string);
   $v = $pt->value($symbol, $string);
 
-Return the atomic value of given the atomic number, name, or symbol
-and a string indicating a unique part of a header name.
+Return the atomic value of the atomic number, name, or symbol and a
+string indicating a unique part of a header name.
 
 =head1 SEE ALSO
 
@@ -277,8 +294,6 @@ The F<t/01-methods.t> file.
 
 L<Moo>
 
-L<Carp>
-
 L<File::ShareDir>
 
 L<List::SomeUtils>
